fuseMount function
Calls function fn when the current Flame component is mounted.
Implementation
void fuseMount(FuseMountFn fn) {
final component = fuseComponent();
component._mountFns.add(fn);
}
Calls function fn when the current Flame component is mounted.
void fuseMount(FuseMountFn fn) {
final component = fuseComponent();
component._mountFns.add(fn);
}