fuseParentResize function
Calls function fn whenever the parent component is resized.
Implementation
void fuseParentResize(FuseParentResizeFn fn) {
final component = fuseComponent();
component._parentResizeFns.add(fn);
}
Calls function fn whenever the parent component is resized.
void fuseParentResize(FuseParentResizeFn fn) {
final component = fuseComponent();
component._parentResizeFns.add(fn);
}